yandex_quick_pay library
Classes
- QuickPayConfig
- QuickPayFailure
- Payment failed.
- QuickPaymentStateListener
- Listener for quick payment state changes.
- QuickPayResult
- Base class for the result of a quick payment operation.
- QuickPaySuccess
- Payment completed successfully.
- YandexActivePaymentMethodBadge
- Widget that displays the active payment method badge.
- YandexPaymentMethodsWidget
- Widget that displays available payment methods and allows managing quick payment settings.
- YandexQuickPay
- Entry point for Yandex Quick Payment SDK.